@@ -1,25 +1,20 @@
 use serde::{Deserialize, Serialize};
-
-use winapi::shared::windef::LPRECT;
-use winapi::um::minwinbase::SECURITY_ATTRIBUTES;
-use winapi::um::winuser::GetWindowRect;
-use winapi::um::{
-    errhandlingapi::GetLastError,
-    handleapi::INVALID_HANDLE_VALUE,
-    memoryapi::{MapViewOfFile, FILE_MAP_ALL_ACCESS},
-    winbase::CreateFileMappingA,
-    winnt::PAGE_READWRITE,
-    winuser::GetWindowThreadProcessId,
-};
-
+#[cfg(target_os = "windows")]
 use winapi::{
     shared::{
         minwindef::{BOOL, LPARAM, LPDWORD},
         ntdef::NULL,
-        windef::HWND,
-        windef::RECT,
+        windef::{HWND, LPRECT, RECT},
+    },
+    um::{
+        errhandlingapi::GetLastError,
+        handleapi::INVALID_HANDLE_VALUE,
+        memoryapi::{MapViewOfFile, FILE_MAP_ALL_ACCESS},
+        minwinbase::SECURITY_ATTRIBUTES,
+        winbase::CreateFileMappingA,
+        winnt::PAGE_READWRITE,
+        winuser::{EnumWindows, GetWindowRect, GetWindowThreadProcessId},
     },
-    um::winuser::EnumWindows,
 };
 
 pub const MUMBLE_LINK_SIZE: usize = 1193;
@@ -101,6 +96,7 @@ pub struct MumbleLink {
 }
 
 impl CMumbleLink {
+    #[cfg(target_os = "windows")]
     pub fn new(key: &str) -> *const CMumbleLink {
         let handle;
         let key_cstr = std::ffi::CString::new(key).unwrap();
@@ -127,6 +123,7 @@ impl CMumbleLink {
         }
         handle as *const CMumbleLink
     }
+    #[cfg(target_os = "windows")]
     pub fn get_win_pos_dim(&self) -> Option<WinPosDim> {
         let link = self;
         if !(*link).is_valid() {
@@ -165,6 +162,7 @@ impl CMumbleLink {
             })
         }
     }
+    #[cfg(target_os = "windows")]
     unsafe extern "system" fn get_handle_by_pid(handle: HWND, lp: LPARAM) -> BOOL {
         let mut handle_pid: u32 = 0;
         GetWindowThreadProcessId(handle, &mut handle_pid as LPDWORD);
